==> versions-common-2.17.1-sources.jar: org/codehaus/mojo/versions/utils/PropertyComparator.java <==
package org.codehaus.mojo.versions.utils;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Comparator;

import org.apache.commons.lang3.StringUtils;
import org.codehaus.mojo.versions.api.Property;

/**
 * A comparator used to sort {@link Property} instances.
 *
 * @since 1.0-beta-1
 */
public enum PropertyComparator implements Comparator<Property> {
    INSTANCE;

    /**
     * Compares to {@link Property} instances.
     *
     * @param p1 the first object
     * @param p2 the second object.
     * @return the comparison result
     * @see java.util.Comparator#compare(Object, Object)
     * @since 1.0-beta-1
     */
    @SuppressWarnings("checkstyle:InnerAssignment")
    public int compare(Property p1, Property p2) {
        int r;
        return p1 == p2
                ? 0
                : p1 == null
                        ? 1
                        : p2 == null
                                ? -1
                                : (r = StringUtils.compare(p1.getName(), p2.getName())) == 0
                                        ? StringUtils.compare(p1.getValue(), p2.getValue())
                                        : r;
    }
}

==> versions-common-2.20.1-sources.jar: org/codehaus/mojo/versions/utils/PropertyComparator.java <==
package org.codehaus.mojo.versions.utils;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Comparator;

import org.codehaus.mojo.versions.api.Property;

/**
 * A comparator used to sort {@link Property} instances.
 *
 * @since 1.0-beta-1
 */
public enum PropertyComparator implements Comparator<Property> {
    /**
     * The singleton instance.
     */
    INSTANCE;

    /**
     * Compares to {@link Property} instances.
     *
     * @param p1 the first object
     * @param p2 the second object.
     * @return the comparison result
     * @see java.util.Comparator#compare(Object, Object)
     * @since 1.0-beta-1
     */
    public int compare(Property p1, Property p2) {
        return Comparator.nullsLast(Comparator.comparing(Property::getName)
                        .thenComparing(Property::getValue, VersionStringComparator.LENIENT))
                .compare(p1, p2);
    }
}
